#  tests for numexpr-2.6.5-py35h7bf3b9c_0 (this is a generated file);
print('===== testing package: numexpr-2.6.5-py35h7bf3b9c_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import sys
import numpy
import numexpr
import numexpr.interpreter

from multiprocessing import freeze_support

if __name__ == "__main__":
    freeze_support()
    numexpr.test()
#  --- run_test.py (end) ---

print('===== numexpr-2.6.5-py35h7bf3b9c_0 OK =====');
print("import: 'numexpr'")
import numexpr

print("import: 'numexpr.interpreter'")
import numexpr.interpreter

